| rsyncrosim | R Documentation |
rsyncrosim provides an interface to SyncroSim, a generalized framework for running and managing scenario-based stochastic simulations over space and time. Different kinds of simulation models can "plug-in" to SyncroSim as packages and take advantage of general features common to many kinds of simulation models, such as defining scenarios of inputs, running Monte Carlo simulations, and viewing charts and maps of outputs.
To learn more about rsyncrosim, start with the vignette tutorial:
browseVignettes("rsyncrosim").
Maintainer: Leonardo Frid rsyncrosim@syncrosim.com
Authors:
Colin Daniel colin.daniel@apexrms.com
Josie Hughes josie.hughes@canada.ca
Valentin Lucet
Alex Embrey
Katie Birchard katie.birchard@apexrms.com
Tabitha Kennedy
Shreeram Senthivasan
Vicki Zhang vicki.zhang@apexrms.com
Hannah Adams hannah.adams@apexrms.com
Other contributors:
ApexRMS [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.