rsyncrosim-package: rsyncrosim: The R Interface to 'SyncroSim'

rsyncrosim-packageR Documentation

rsyncrosim: The R Interface to 'SyncroSim'

Description

logo

'SyncroSim' is a generalized framework for managing scenario-based datasets (https://syncrosim.com/). 'rsyncrosim' provides an interface to 'SyncroSim'. Simulation models can be added to 'SyncroSim' in order to transform these datasets, taking advantage of general features such as defining scenarios of model inputs, running Monte Carlo simulations, and summarizing model outputs. 'rsyncrosim' requires 'SyncroSim' 2.3.5 or higher (API documentation: https://docs.syncrosim.com/).

Author(s)

Maintainer: Leonardo Frid rsyncrosim@syncrosim.com

Authors:

Other contributors:

  • ApexRMS [copyright holder]

See Also

Useful links:


rsyncrosim documentation built on March 24, 2026, 9:07 a.m.