| rsyncrosim-package | R Documentation |
'SyncroSim' is a generalized framework for managing scenario-based datasets (https://syncrosim.com/). 'rsyncrosim' provides an interface to 'SyncroSim'. Simulation models can be added to 'SyncroSim' in order to transform these datasets, taking advantage of general features such as defining scenarios of model inputs, running Monte Carlo simulations, and summarizing model outputs. 'rsyncrosim' requires 'SyncroSim' 2.3.5 or higher (API documentation: https://docs.syncrosim.com/).
Maintainer: Leonardo Frid rsyncrosim@syncrosim.com
Authors:
Colin Daniel colin.daniel@apexrms.com
Josie Hughes josie.hughes@canada.ca
Valentin Lucet
Alex Embrey
Katie Birchard katie.birchard@apexrms.com
Tabitha Kennedy
Shreeram Senthivasan
Vicki Zhang vicki.zhang@apexrms.com
Hannah Adams hannah.adams@apexrms.com
Other contributors:
ApexRMS [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.